pub struct Create {
pub _name: String,
pub _symbol: String,
pub _uri: String,
pub _creator: Pubkey,
}Expand description
Instruction.
Fields
_name: String_symbol: String_uri: String_creator: PubkeyTrait Implementations
Sourceimpl BorshDeserialize for Create
impl BorshDeserialize for Create
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Create
impl BorshSerialize for Create
Sourceimpl Discriminator for Create
impl Discriminator for Create
const DISCRIMINATOR: [u8; 8]
fn discriminator() -> [u8; 8]
Sourceimpl InstructionData for Create
impl InstructionData for Create